@@ -8,19 +8,13 @@ OC.L10N.register(
     "Rename" : "Hernoem",
     "Move" : "Skuif",
     "Delete" : "Skrap",
+    "Select all" : "Kies alle",
     "New" : "Nuut",
     "New folder" : "Nuwe vouer",
-    "List view" : "Lysaansig",
-    "Select all" : "Kies alle",
     "Cancel" : "Kanselleer",
     "Recent" : "Onlangs",
-    "Add a bookmark" : "Voeg 'n boekmerk by",
     "Import" : "Voer In",
     "Export" : "Voer uit",
-    "Recently added" : "Onlangs bygevoeg",
-    "Alphabetically" : "Alfabeties",
-    "Most visited" : "Meeste besoek",
-    "Last modified" : "Laas gewysig",
     "Bookmarklet" : "Boekmerkie",
     "Delete all bookmarks" : "Skrap alle boekmerke",
     "Title" : "Titel",
@@ -32,9 +26,9 @@ OC.L10N.register(
     "Copy link" : "Kopieer skakel",
     "Allow editing" : "Laat redigering toe",
     "Link copied" : "Skakel gekopieer",
-    "Select" : "Kies",
-    "Previews" : "Voorskoue",
     "Privacy" : "Privaatheid",
+    "Previews" : "Voorskoue",
+    "Add a bookmark" : "Voeg 'n boekmerk by",
     "This URL is already bookmarked! Overwrite?" : "'n Boekmerk van die URL bestaan reeds. Skryf oor?",
     "Folder" : "Vouer",
     "Save" : "Stoor"
