@@ -5,17 +5,14 @@ OC.L10N.register(
     "Rename" : "Adenvel",
     "Move" : "Diplasañ",
     "Delete" : "Dilemel",
+    "Select all" : "Dibab pep tra",
     "New" : "Nevez",
     "New folder" : "Heuliad nevez",
-    "Grid view" : "Diskwell ar roued",
-    "List view" : "Gwelidik listenn",
-    "Select all" : "Dibab pep tra",
     "Submit" : "Kinnig",
     "Cancel" : "Arrest",
     "Recent" : "Nevez",
     "Broken links" : "Liammoù toret",
     "Import" : "Emporzhiañ ",
-    "Recently added" : "Ouzpennet n'eus ket pel zo",
     "Enter the path of a folder where bookmarked files should be stored" : "Lakait hent an teuliad lec'h ma vo enrollet ar restroù gant ur merket pajenn",
     "Clear data" : "Lemel ar roadennoù",
     "Link" : "Liamm",
@@ -26,7 +23,6 @@ OC.L10N.register(
     "Copy link" : "Kopiañ al liamm",
     "Allow editing" : "Cheñchamentoù aotreet",
     "Link copied" : "Liamm eilet",
-    "Select" : "Dibab",
     "Privacy" : "Prevezder",
     "Folder" : "Teuliad",
     "Save" : "Enrollañ"
