@@ -5,17 +5,12 @@ OC.L10N.register(
     "Rename" : "Ailenwi",
     "Move" : "Symud",
     "Delete" : "Dileu",
-    "Search" : "Chwilio",
     "New" : "Newydd",
     "New folder" : "Ffolder newydd",
-    "Grid view" : "Golwg grid",
-    "List view" : "Golwg rhestr",
     "Cancel" : "Diddymu",
     "Recent" : "Diweddar",
     "Import" : "Mewnforio",
     "Export" : "Allforio",
-    "Recently added" : "Ychwanegwyd yn ddiweddar",
-    "Last modified" : "Newidiwyd diwethaf",
     "Title" : "Teitl",
     "Link" : "Dolen",
     "Tags" : "Tagiau",
@@ -23,7 +18,6 @@ OC.L10N.register(
     "Owner" : "Owner",
     "Share link" : "Rhannu dolen",
     "Copy link" : "Copïo dolen",
-    "Select" : "Select",
     "Folder" : "Plygell",
     "Save" : "Cadw"
 },
