@@ -4,25 +4,21 @@ OC.L10N.register(
     "Bookmarks" : "Bookmarks",
     "No file provided for import" : "هیچ پرونده ای برای واردکردن ارائه نشده است",
     "Unsupported file type for import" : "این نوع فایل برای افزودن پشتیبانی نمی شود",
-    "Recent Bookmarks" : "نشانک های اخیر",
     "A Bookmark manager for Nextcloud" : "یک مدیر نشانک برای نکست کلود",
     "Select bookmark" : "نشانک را انتخاب کنید",
     "Details" : "جزئیات",
     "Rename" : "تغییرنام",
     "Move" : "انتقال",
     "Delete" : "حذف",
-    "Select one or more tags" : "یک یا چند تگ را انتخاب کنید",
-    "New" : "جدید",
-    "New folder" : "پوشه جدید",
-    "Grid view" : "نمایش گرید",
-    "List view" : "نمایش لیست",
     "Move selection" : "انتخاب را جابجا کنید",
     "Delete selection" : "انتخاب را حذف کنید",
     "Select all" : "انتخاب همه",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["انتخاب شده %n نشانک","انتخاب شده %n نشانک های"],
+    "Select one or more tags" : "یک یا چند تگ را انتخاب کنید",
+    "New" : "جدید",
+    "New folder" : "پوشه جدید",
     "Enter a link" : "پیوند را وارد کنید",
     "Enter folder title" : "عنوان پوشه را وارد کنید",
-    "Root folder" : "پوشهٔ ریشه",
     "Submit" : "ارسال",
     "Cancel" : "لغو",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["در حال انتقال %nپوشه ها و برخی نشانک ها","در حال انتقال %n پوشه ها و برخی نشانک ها"],
@@ -31,14 +27,8 @@ OC.L10N.register(
     "Recent" : "اخیر",
     "Untagged" : "غیرقابل تشخیص",
     "No bookmarks here" : "در اینجا هیچ نشانک وجود ندارد",
-    "Add a bookmark" : "یک نشانک اضافه کنید",
     "Import" : "وارد کردن",
     "Export" : "گرفتن خروجی",
-    "Sorting" : "مرتب سازی",
-    "Recently added" : "اخیرا اضافه شده ",
-    "Alphabetically" : "الفبایی",
-    "Most visited" : "بیشترین بازدید",
-    "Last modified" : "آخرین اصلاح شده",
     "Client apps" : "برنامه های مشتری",
     "Also check out the collection of client apps that integrate with this app: " : "همچنین مجموعه برنامه های مشتری که با این برنامه ادغام شده اند را بررسی کنید:",
     "Bookmarklet" : "نشانک",
@@ -49,11 +39,8 @@ OC.L10N.register(
     "Do you really want to delete all your bookmarks?" : "آیا واقعاً می خواهید تمام نشانک های خود را حذف کنید؟",
     "Title" : "عنوان",
     "Link" : "Link",
-    "Creation date" : "تاریخ ایجاد",
     "Tags" : "برچسب‌ها",
-    "Attachments" : "پیوست‌ها",
     "Notes" : "یادداشت ها",
-    "{time} ago" : "{time} قبل",
     "Owner" : "صاحب",
     "Sharing" : "اشتراک گذاری",
     "Select a user or group" : "کاربر یا گروهی را انتخاب کنید",
@@ -61,19 +48,19 @@ OC.L10N.register(
     "Copy link" : "کپی کردن لینک",
     "Allow editing" : "اجازه‌ی ویرایش",
     "Link copied" : "پیوند کپی شد",
-    "Select" : "انتخاب",
-    "Previews" : "پیش نمایش ها",
-    "Screeenly" : "صفحه نمایش",
-    "You can either sign up for free at screeenly.com or setup your own server." : "می توانید به صورت رایگان در screeenly.com ثبت نام کنید یا سرور خود را راه اندازی کنید.",
-    "Screeenly API URL" : "Screeenly API URL",
-    "Screeenly API key" : "Screeenly API key",
     "Privacy" : "حریم خصوصی",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "نشانک ها سعی می کنند به صفحات وب اضافه شده دسترسی پیدا کنند تا به طور خودکار اطلاعات مربوط به آنها اضافه شود.",
     "Enable accessing and collecting information from the web pages you add" : "دسترسی و جمع آوری اطلاعات از صفحات وب اضافه شده را فعال کنید",
     "Performance" : "کارایی",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "حداکثر تعداد نشانک های مجاز در هر حساب. (0 بدون محدودیت است ؛ پیش فرض هیچ محدودیتی نیست)",
+    "Previews" : "پیش نمایش ها",
+    "Screeenly" : "صفحه نمایش",
+    "You can either sign up for free at screeenly.com or setup your own server." : "می توانید به صورت رایگان در screeenly.com ثبت نام کنید یا سرور خود را راه اندازی کنید.",
+    "Screeenly API URL" : "Screeenly API URL",
+    "Screeenly API key" : "Screeenly API key",
     "Failed to load settings" : "تنظیمات بارگیری نشد",
     "Failed to save settings" : "تنظیمات ذخیره نشدند",
+    "Add a bookmark" : "یک نشانک اضافه کنید",
     "This URL is already bookmarked! Overwrite?" : "این URL از قبل نشانک گذاری شده است! دوباره نشانک گذاری شود؟",
     "Enter bookmark title" : "عنوان نشانک را وارد کنید",
     "Enter bookmark URL" : "URL نشانک را وارد کنید",
