@@ -5,25 +5,22 @@ OC.L10N.register(
     "Rename" : "Renominar",
     "Move" : "Mover",
     "Delete" : "Deler",
+    "Select all" : "Selectionar toto",
     "New" : "Nove",
     "New folder" : "Nove dossier",
-    "Select all" : "Selectionar toto",
     "Cancel" : "Cancellar",
     "Recent" : "Recente",
     "Import" : "Importar",
     "Export" : "Exportar",
-    "Alphabetically" : "Alphabeticamente",
     "Title" : "Titulo",
     "Link" : "Ligamine",
     "Tags" : "Etiquettas",
-    "Attachments" : "Attachamentos",
     "Notes" : "Notas",
     "Owner" : "Owner",
     "Sharing" : "Compartente",
     "Share link" : "Compartir ligamine",
     "Copy link" : "Copiar ligamine",
     "Allow editing" : "Permitter modificar",
-    "Select" : "Selectionar",
     "Folder" : "Dossier",
     "Save" : "Salveguardar"
 },
