@@ -5,32 +5,29 @@ OC.L10N.register(
     "No file provided for import" : "Engin skrá valin til innflutnings",
     "Unsupported file type for import" : "Ekki er hægt að flytja inn þessa tegund af bókamerki",
     "Bookmarks shared by %s" : "Bókamerki deilt af %s",
-    "Recent Bookmarks" : "Nýleg bókamerki",
     "A Bookmark manager for Nextcloud" : "Bókamerkjastjóri fyrir Nextcloud",
     "Select bookmark" : "Veldu bókamerki",
     "Details" : "Nánar",
     "Rename" : "Endurnefna",
     "Move" : "Færa",
     "Delete" : "Eyða",
-    "Select one or more tags" : "Veldu eitt eða fleiri merki",
-    "New" : "Nýtt",
-    "New bookmark" : "Nýtt bókamerki",
-    "New folder" : "Ný mappa",
-    "Grid view" : "Reitasýn",
-    "List view" : "Listasýn",
+    "Open all selected" : "Opna allt valið",
     "Move selection" : "Færa valið",
     "Delete selection" : "Eyða vali",
-    "Open all selected" : "Opna allt valið",
     "Select all" : "Select all",
     "Cancel selection" : "Hætta við val",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Valdar {folders} möppur og {bookmarks} bókamerki",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valdi %n bókamerki","Valdi %n bókamerki"],
     "_Selected %n folder_::_Selected %n folders_" : ["Valin %n mappa","Valdar %n möppur"],
+    "Select one or more tags" : "Veldu eitt eða fleiri merki",
+    "New" : "Nýtt",
+    "New bookmark" : "Nýtt bókamerki",
+    "New folder" : "Ný mappa",
+    "RSS feed copied" : "RSS-fréttastreymi afritað",
     "Enter a link" : "Settu inn slóð",
     "Select folder" : "Veldu möppu",
     "Enter folder title" : "Settu inn heiti möppu",
     "Shared by {user}" : "Deilt af {user}",
-    "Root folder" : "Rótarmappa",
     "Submit" : "Senda inn",
     "Cancel" : "Hætta við",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Færi %n möppu og einhver bókamerki","Færi %n möppur og einhver bókamerki"],
@@ -41,14 +38,8 @@ OC.L10N.register(
     "Untagged" : "Ómerkt",
     "{used} bookmarks of {available} available" : "{used} bókamerki af {available} tiltækum",
     "No bookmarks here" : "Engin bókamerki hér",
-    "Add a bookmark" : "Bæta við bókamerki",
     "Import" : "Flytja inn",
     "Export" : "Flytja út",
-    "Sorting" : "Röðun",
-    "Recently added" : "Nýlega bætt við",
-    "Alphabetically" : "Í stafrófsröð",
-    "Most visited" : "Mest heimsótt",
-    "Last modified" : "Síðast breytt",
     "Client apps" : "Biðlaraforrit",
     "Also check out the collection of client apps that integrate with this app: " : "Skoðaðu einnig úrval þeirra biðlaraforrita sem samþættast þessu forriti:",
     "Bookmarklet" : "Bókamerklingur",
@@ -59,11 +50,8 @@ OC.L10N.register(
     "Do you really want to delete all your bookmarks?" : "Viltu í alvörunni eyða öllum bókmerkjunum þínum?",
     "Title" : "Titill",
     "Link" : "Tengill",
-    "Creation date" : "Upprunadagsetning",
     "Tags" : "Merki",
-    "Attachments" : "Viðhengi",
     "Notes" : "Minnispunktar",
-    "{time} ago" : "fyrir {time} síðan",
     "Owner" : "Eigandi",
     "Sharing" : "Deiling",
     "Select a user or group" : "Veldu notanda eða hóp",
@@ -73,23 +61,21 @@ OC.L10N.register(
     "Delete link" : "Eyða tengli",
     "Create public link" : "Búa til opinberan tengil",
     "Allow editing" : "Leyfa breytingar",
-    "Allow sharing" : "Leyfa deilingu",
     "Remove share" : "Fjarlægja sameign",
     "Link copied" : "Tengill afritaður",
-    "RSS feed copied" : "RSS-fréttastreymi afritað",
-    "Select" : "Velja",
-    "Previews" : "Forskoðun",
-    "Screeenly" : "Screeenly",
-    "You can either sign up for free at screeenly.com or setup your own server." : "Þú getur annað hvort skráð þig ókeypis á  screeenly.com eða sett upp þinn eigin þjón.",
-    "Screeenly API URL" : "Slóð á API-forritsviðmót Screenly",
-    "Screeenly API key" : "Screeenly API-lykill",
     "Privacy" : "Gagnaleynd",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "Bókamerkjaforritið mun reyna að fá aðgang að þeim síðum sem þú bætir við til að sækja sjálfvirkt upplýsingar um þær.",
     "Enable accessing and collecting information from the web pages you add" : "Virkja aðgang og söfnun upplýsinga af vefsíðunum sem þú bætir við",
     "Performance" : "Afköst",
     "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Leyfður hámarksföldi bókamerkja á hvern notandaaðgang. (0 fyrir engin takmörk; það er sjálfgefið)",
+    "Previews" : "Forskoðun",
+    "Screeenly" : "Screeenly",
+    "You can either sign up for free at screeenly.com or setup your own server." : "Þú getur annað hvort skráð þig ókeypis á  screeenly.com eða sett upp þinn eigin þjón.",
+    "Screeenly API URL" : "Slóð á API-forritsviðmót Screenly",
+    "Screeenly API key" : "Screeenly API-lykill",
     "Failed to load settings" : "Mistókst að hlaða inn stillingum",
     "Failed to save settings" : "Mistókst að vista stillingar",
+    "Add a bookmark" : "Bæta við bókamerki",
     "This URL is already bookmarked! Overwrite?" : "Þessi slóð er þegar bókamerkt! Skrifa yfir?",
     "Enter bookmark title" : "Settu inn titil á bókamerki",
     "Enter bookmark URL" : "Settu inn slóð á bókamerki",
