@@ -20,40 +20,28 @@ OC.L10N.register(
     "Someone shared folder \"%s\" with you" : "Noen delte mappen \"%s\" med deg",
     "No file provided for import" : "Ingen fil valgt for import",
     "Unsupported file type for import" : "Usupportert filtype for import",
-    "Recent Bookmarks" : "Nylige bokmerker",
     "Details" : "Detaljer",
     "Rename" : "Gi nytt navn",
     "Move" : "Flytt",
     "Delete" : "Slett",
+    "Select all" : "Velg alle",
     "Select one or more tags" : "Velg en eller flere merkelapper",
     "New" : "Ny",
     "New folder" : "Ny mappe",
-    "Grid view" : "Rutenett-visning",
-    "List view" : "Listevisning",
-    "Select all" : "Velg alle",
     "Enter a link" : "Skriv inn et lenke",
     "Enter folder title" : "Skriv inn tittel",
-    "Root folder" : "Hovedmappe",
     "Submit" : "Send inn",
     "Cancel" : "Avbryt",
     "Recent" : "Nylig",
-    "Add a bookmark" : "Legg til bokmerke",
     "Import" : "Importer",
     "Export" : "Eksporter",
-    "Sorting" : "Sorter",
-    "Recently added" : "Nylig lagt til",
-    "Alphabetically" : "Alfabetisk",
-    "Most visited" : "Mest besøkt",
-    "Last modified" : "Sist redigert",
     "Bookmarklet" : "Bookmarklet",
     "Clear data" : "Tøm data",
     "Delete all bookmarks" : "Slett alle bokmerker",
     "Do you really want to delete all your bookmarks?" : "Er du sikker på at du vil slette alle dine bokmerker",
     "Title" : "Tittel",
     "Link" : "Lenke",
-    "Creation date" : "Opprettelses dato",
     "Tags" : "Merkelapper",
-    "Attachments" : "Vedlegg",
     "Notes" : "Notater",
     "Owner" : "Eier",
     "Sharing" : "Deling",
@@ -61,11 +49,11 @@ OC.L10N.register(
     "Copy link" : "Kopier lenke",
     "Allow editing" : "Tillat redigering",
     "Link copied" : "Lenke kopiert",
-    "Select" : "Velg",
     "Privacy" : "Personvern",
     "Performance" : "Ytelse",
     "Failed to load settings" : "Klarte ikke å laste inn innstillinger",
     "Failed to save settings" : "Klarte ikke å lagre innstillinger",
+    "Add a bookmark" : "Legg til bokmerke",
     "This URL is already bookmarked! Overwrite?" : "Denne lenken eksisterer allerede, ønsker du overskrive?",
     "Enter bookmark title" : "Skriv inn tittel",
     "Folder" : "Mappe",
