@@ -6,26 +6,19 @@ OC.L10N.register(
     "Rename" : "Renomear",
     "Move" : "Mover",
     "Delete" : "Apagar",
+    "Select all" : "Seleccionar todos",
     "New" : "Novo",
     "New folder" : "Nova pasta",
-    "Grid view" : "Vista em grelha",
-    "List view" : "Vista em lista",
-    "Select all" : "Seleccionar todos",
-    "Root folder" : "Pasta raiz",
     "Submit" : "Submeter",
     "Cancel" : "Cancelar",
     "All bookmarks" : "Todos os marcadores",
     "Recent" : "Recentes",
-    "Add a bookmark" : "Adicionar um marcador",
     "Import" : "Importar",
     "Export" : "Exportar",
-    "Recently added" : "Adicionados recentemente",
-    "Last modified" : "Última modificação",
     "Clear data" : "Limpar dados",
     "Title" : "Título",
     "Link" : "Link",
     "Tags" : "Marcações",
-    "Attachments" : "Anexos",
     "Notes" : "Notas",
     "Owner" : "Proprietário",
     "Sharing" : "Partilha",
@@ -34,8 +27,8 @@ OC.L10N.register(
     "Copy link" : "Copiar hiperligação",
     "Allow editing" : "Permitir edição",
     "Link copied" : "Link copiado",
-    "Select" : "Seleccionar",
     "Privacy" : "Privacidade",
+    "Add a bookmark" : "Adicionar um marcador",
     "Folder" : "Pasta",
     "Save" : "Guardar"
 },
