@@ -5,27 +5,20 @@ OC.L10N.register(
     "Rename" : "Rename",
     "Move" : "Zhvendos",
     "Delete" : "Fshij",
+    "Select all" : "Zgjidhi të gjitha",
     "New" : "I ri",
     "New folder" : "Dosje e re",
-    "Grid view" : "Pamje galeri",
-    "List view" : "Pamje listë",
-    "Select all" : "Zgjidhi të gjitha",
     "Submit" : "Dërgo",
     "Cancel" : "Anullo",
     "Recent" : "Së fundmi",
     "Untagged" : "E paetiketuar",
     "Import" : "Import",
     "Export" : "Eksport",
-    "Recently added" : "Shtuar së fundmi",
-    "Alphabetically" : "Alfabetikisht",
-    "Most visited" : "Vizituar më shpesh",
-    "Last modified" : "Ndryshuar së fundmi",
     "Bookmarklet" : "Libër Shënues",
     "Clear data" : "Pastroji të dhënat",
     "Title" : "Titulli",
     "Link" : "Lidhje",
     "Tags" : "Etiketat",
-    "Attachments" : "Bashkangjitjet",
     "Notes" : "Shënime",
     "Owner" : "Zotëruesi",
     "Sharing" : "Ndarje",
@@ -33,9 +26,8 @@ OC.L10N.register(
     "Copy link" : "Kopjo linkun",
     "Allow editing" : "Lejo redaktimin",
     "Link copied" : "Linku u kopjua",
-    "Select" : "Përzgjidh",
-    "Previews" : "Parapamjet",
     "Privacy" : "Privatësia",
+    "Previews" : "Parapamjet",
     "Folder" : "Skedari",
     "Save" : "Ruaj"
 },
