@@ -28,6 +28,8 @@ OC.L10N.register(
     "No file provided for import" : "Inga filer given för importering",
     "Unsupported file type for import" : "Ogiltig filtyp för import",
     "Bookmarks shared by %s" : "Bokmärken delas av %s",
+    "Frequent bookmarks" : "Vanliga bokmärken",
+    "Recent bookmarks" : "Senaste bokmärken",
     "Bookmark" : "Bokmärke",
     "Bookmark deleted" : "Bokmärke raderat",
     "Bookmark created" : "Bokmärke skapat",
@@ -42,42 +44,81 @@ OC.L10N.register(
     "Rename" : "Byt namn",
     "Move" : "Flytta",
     "Delete" : "Ta bort",
+    "Do you really want to delete this bookmark?" : "Är du säker att du vill ta bort detta bokmärket?",
+    "Content pending" : "Innehåll förestår",
+    "This content is being downloaded for offline use. Please check back later." : "Detta innehåll laddas ner för offlineanvändning. Vänligen försök igen senare.",
     "Open all selected" : "Öppna alla markerade",
     "Move selection" : "Flytta urval",
+    "Edit tags of selection" : "Ändra taggar för urval",
     "Delete selection" : "Ta bort urval",
     "Select all" : "Välj alla",
     "Cancel selection" : "Avbryt markering",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Valde {folders} mappar och {bookmarks} bokmärken",
+    "Do you really want to delete these items?" : "Är du säker att du vill ta bort dessa objekt?",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valde %n bokmärke","Valde %n bokmärken"],
+    "_Selected %n folder_::_Selected %n folders_" : ["Valde %n mapp","Valde %n mappar"],
+    "Go back" : "Gå tillbaks",
+    "Share folder" : "Dela mapp",
     "Select one or more tags" : "Välj en eller flera taggar",
     "New" : "Nytt",
     "New bookmark" : "Nytt bokmärke",
     "New folder" : "Ny mapp",
+    "Change to grid view" : "Växla till rutnätsvy",
+    "Change to list view" : "Växla till listvy",
+    "Copy RSS Feed of current view" : "Kopiera RSS-flöde för aktuella vyn",
+    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS-flödet kräver autentisering med dina Nextcloud-uppgifter",
+    "Sort by created date" : "Sortera efter skapat datum",
+    "Sort by last modified" : "Sortera efter senast modifierad",
+    "Sort by title" : "Sortera efter titel",
+    "Sort by click count" : "Sortera efter antal klicks",
+    "Sort by manual order" : "Sortera efter manuell ordning",
     "RSS feed copied" : "Kopierade RSS flöde",
     "Enter a link" : "Ange en länk",
     "Enter a title" : "Ange en titel",
+    "No bookmarks found" : "Inga bokmärken hittades",
+    "{folders} folders and {bookmarks} bookmarks" : "{folders} mappar och {bookmarks} bokmärken",
+    "_%n bookmark_::_%n bookmarks_" : ["%n bokmärke","%n bokmärken"],
+    "_%n folder_::_%n folders_" : ["%n mapp","%n mappar"],
     "Select folder" : "Välj mapp",
     "Enter folder title" : "Ange titel",
     "Shared by {user}" : "Delad av {user}",
+    "Rename folder" : "Byt namn på mapp",
+    "Move folder" : "Flytta mapp",
+    "Delete folder" : "Ta bort mapp",
+    "Do you really want to delete this folder?" : "Är du säker att du vill ta bort denna mappen?",
+    "Choose folder" : "Välj mapp",
     "Submit" : "Verkställ",
     "Cancel" : "Avbryt",
+    "Deleting bookmarks" : "Tar bort bokmärken",
+    "Deleting selection" : "Tar bort urval",
+    "Importing bookmarks" : "Importerar bokmärken",
+    "Moving selection" : "Flyttar urval",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Flyttar %n mapp och några bokmärken","Flyttar %n mappar och några bokmärken"],
     "_Moving %n folder_::_Moving %n folders_" : ["Flyttar %n mapp","Flyttar %n mappar"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Flyttar %n bokmärke","Flyttar %n bokmärken"],
     "All bookmarks" : "Alla bokmärken",
     "Recent" : "Nya",
+    "Files" : "Filer",
     "Broken links" : "Brutna länkar",
+    "New tag" : "Ny tagg",
+    "Search tags" : "Sök taggar",
     "Untagged" : "Inte taggad",
     "{used} bookmarks of {available} available" : "{used} bokmärken av {available} tillgängliga",
+    "No bookmarked files" : "Inga bokmärkta filer",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bokmärken till filer som foton eller PDF-filer sparas automatiskt i ditt Nextcloud så att du fortfarande kan hitta dem även när länken går offline.",
     "No bookmarks here" : "Inga bokmärken här",
+    "Start by importing bookmarks from a file or synchronizing your browser bookmarks with this app" : "Börja med att importera bokmärken från en fil eller synkronisera dina webbläsarbokmärken med denna appen",
     "Import bookmarks" : "Importera bokmärken",
+    "Sync with your browser" : "Synkronisera med din webbläsare",
     "Import" : "Importera",
     "Export" : "Exportera",
     "Archive path" : "Sökväg till arkiv",
     "Enter the path of a folder where bookmarked files should be stored" : "Ange sökvägen till en mapp där bokmärkta filer ska lagras",
     "Client apps" : "Klientappar",
     "Also check out the collection of client apps that integrate with this app: " : "Kolla också in samlingen av klientappar som integrerar med den här appen: ",
+    "Install web app on device" : "Installera webbapp på denna enhet",
+    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Du kan installera denna appen på hemskärmen av din enhet för att snabbt komma åt dina bokmärken från din mobil. Du kan enkelt ta bort appen från hemskärmen igen ifall du inte gillar det.",
+    "Install on home screen" : "Installera på hemskärmen",
     "Bookmarklet" : "Bookmarklet",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Dra till webbläsarens bokmärken och klicka på den för att snabbt bokmärka en webbplats",
     "Add to {instanceName}" : "Lägg till {instanceName}",
@@ -85,20 +126,31 @@ OC.L10N.register(
     "Permanently remove all bookmarks from your account." : "Ta bort alla bokmärken från ditt konto permanent.",
     "Delete all bookmarks" : "Ta bort alla bokmärken",
     "Do you really want to delete all your bookmarks?" : "Vill du verkligen radera alla dina bokmärken?",
+    "Please select \"Add to home screen\" in your browser menu" : "Vänligen välj \"Lägg till hemskärm\" i din webbläsarmeny",
     "Title" : "Titel",
     "Link" : "Länk",
     "Tags" : "Taggar",
     "Select tags and create new ones" : "Välj taggar och skapa nya",
     "Notes" : "Anteckning",
+    "Notes for this bookmark …" : "Anteckningar för detta bokmärket …",
+    "Archived file" : "Arkiverad fil",
+    "Open file" : "Öppna fil",
+    "Open file location" : "Öppna filsökväg",
+    "Created {time} ago" : "Skapad för {time} sedan",
+    "Created on {date}" : "Skapades {date}",
     "Owner" : "Ägare",
     "Sharing" : "Delning",
     "Select a user or group" : "Välj en användare eller grupp",
     "Share link" : "Dela länk",
+    "Reading allowed" : "Läsning tillåten",
     "Copy link" : "Kopiera länk",
     "Copy RSS feed" : "Kopiera RSS-flöde",
     "Delete link" : "Ta bort länk",
     "Create public link" : "Skapa offentlig länk",
+    "Resharing allowed" : "Vidaredelning tillåten",
+    "Editing allowed" : "Redigering tillåten",
     "Allow editing" : "Tillåt redigering",
+    "Allow resharing" : "Tillåt vidaredelning",
     "Remove share" : "Ta bort delning",
     "Link copied" : "Länk kopierad",
     "Privacy" : "Integritet",
@@ -128,6 +180,7 @@ OC.L10N.register(
     "Folder" : "Mapp",
     "Root Folder" : "Rot mapp",
     "Save" : "Spara",
+    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Nätverkstillgång är inaktiv som standard. Gå till administratör-inställningarna för bokmärkesappen för att tillåta hämtning av förhandsvisningar och ikoner.",
     "Failed to count unavailable bookmarks" : "Det gick inte att räkna otillgängliga bokmärken",
     "Failed to count archived bookmarks" : "Det gick inte att räkna arkiverade bokmärken",
     "Failed to load bookmark" : "Det gick inte att läsa in bokmärket",
