@@ -5,16 +5,12 @@ OC.L10N.register(
     "Rename" : "เปลี่ยนชื่อ",
     "Move" : "Move",
     "Delete" : "ลบ",
-    "Search" : "Search",
+    "Select all" : "เลือกทั้งหมด",
     "New" : "ใหม่",
     "New folder" : "โฟลเดอร์ใหม่",
-    "Grid view" : "มุมมองแบบตาราง Grid",
-    "List view" : "มุมมองแบบแสดงรายการ",
-    "Select all" : "เลือกทั้งหมด",
     "Cancel" : "ยกเลิก",
     "Import" : "นำเข้า",
     "Export" : "ส่งออก",
-    "Alphabetically" : "เรียงตามตัวอักษร",
     "Title" : "ชื่อเรื่อง",
     "Link" : "ลิงค์",
     "Tags" : "ป้ายกำกับ",
@@ -24,7 +20,6 @@ OC.L10N.register(
     "Share link" : "แชร์ลิงค์",
     "Copy link" : "คัดลอกลิงค์",
     "Allow editing" : "อนุญาตให้แก้ไข",
-    "Select" : "Select",
     "Folder" : "แฟ้มเอกสาร",
     "Save" : "บันทึก"
 },
