@@ -4,12 +4,12 @@ OC.L10N.register(
     "Rename" : "Nomni o'zgartiring",
     "Move" : "Ko'chiring",
     "Delete" : "O'chir",
-    "Save" : "Saqlash",
     "Cancel" : "Bekor qilish",
+    "Link" : "Ulanish",
     "Tags" : "Teglar",
     "Notes" : "Eslatmalar",
     "Share link" : "Ulanishni ulashing",
     "Allow editing" : "Tahrirlashga ruxsat bering",
-    "Link" : "Ulanish"
+    "Save" : "Saqlash"
 },
 "nplurals=1; plural=0;");
