@@ -6,36 +6,30 @@ OC.L10N.register(
     "Rename" : "Đổi tên",
     "Move" : "Dịch chuyển",
     "Delete" : "Xóa",
+    "Select all" : "Chọn tất cả",
     "Select one or more tags" : "Chọn một hoặc nhiều thẻ",
     "New" : "Tạo mới",
     "New folder" : "Tạo thư mục",
-    "Grid view" : "Xem dạng Lưới",
-    "List view" : "Xem dạng Danh sách",
-    "Select all" : "Chọn tất cả",
     "Enter folder title" : "Nhập tiêu đề thư mục",
     "Submit" : "Gửi đi",
     "Cancel" : "Hủy bỏ",
     "Recent" : "Gần đây",
-    "Add a bookmark" : "Thêm một bookmark",
     "Import" : "Nhập vào",
     "Export" : "Xuất ra",
-    "Recently added" : "Mới thêm",
-    "Last modified" : "Lần cuối chỉnh sửa",
     "Clear data" : "Xóa dữ liệu",
     "Title" : "Tên",
     "Link" : "Liên kết",
     "Tags" : "Thẻ",
-    "Attachments" : "Đính kèm",
     "Notes" : "Ghi chép",
     "Owner" : "Chủ",
     "Sharing" : "Đang chia sẽ",
     "Share link" : "Chia sẽ liên kết",
     "Copy link" : "Sao chép liên kết",
     "Allow editing" : "Cho phép chỉnh sửa",
-    "Select" : "Select",
     "Privacy" : "Riêng tư",
     "Failed to load settings" : "Tải cấu hình thất bại",
     "Failed to save settings" : "Lưu cấu hình thất bại",
+    "Add a bookmark" : "Thêm một bookmark",
     "Enter bookmark title" : "Nhập tiêu đề bookmark",
     "Folder" : "Thư mục",
     "Root Folder" : "Thư mục gốc",
